#ifndef _RMAP_STRUCT_H
#define _RMAP_STRUCT_H

#include "regionMapClient.h"

/* Some general constants and definitions */
#define	RMAP_MAX_STRLEN	1024

typedef enum rmapBoolean {RMAP_FALSE, 
			      RMAP_TRUE} rmapBoolean;
typedef enum rmapFusionType {RMAP_OVERRIDE,
			       RMAP_MERGE}
  rmapFusionType;

/* Initialization parameters */
#define RMAP_DFLT_SCALE	1.0
#define RMAP_DFLT_NB_X	400
#define RMAP_DFLT_NB_Y	400
#define RMAP_DFLT_X0	(- 10.0)
#define RMAP_DFLT_Y0	(- 10.0)
#define RMAP_DFLT_ROBOT_RADIUS	1.0
#define RMAP_DFLT_FUSION_TYPE		RMAP_OVERRIDE
#define RMAP_DFLT_PROTOS_FILENAME	"/tmp/velodynePrototypes.psp"
#define RMAP_DFLT_POM_POSTER		"pomPos"

typedef struct rmapInitParams {
  double		scale;
  int		nbX;
  int		nbY;		/* Nb pixels of the map */
  double		xOrigin;
  double      	yOrigin;	/* Position of the map origin in the global
				   frame */ 
  double		robotRadius; /* Radius of the robot */
  rmapFusionType	fusionType;  /* Kind of fusion algorithm used */
  char		protosFileName[RMAP_MAX_STRLEN];
  char		pomPosPoster[RMAP_MAX_STRLEN];
} rmapInitParams;


/* Indicates to which module producing 3D data we are connected */
typedef enum rmapConnection {
  RMAP_NO_CONNECTION,
  RMAP_STEREOPIXEL_CONNECTION,
  RMAP_VELODYNE_CONNECTION
} rmapConnection;

#define RMAP_DFLT_CONNECTION RMAP_STEREOPIXEL_CONNECTION
#define RMAP_DFLT_STEREOPIXEL_POSTER "stereopixelThreeDImage"
#define RMAP_DFLT_VELODYNE_POSTER "velodyneThreeDImage"

typedef struct rmapConnectionParams {
  rmapConnection		connection;
  char			stereopixelPoster[RMAP_MAX_STRLEN];
  char			velodynePoster[RMAP_MAX_STRLEN];
} rmapConnectionParams;

/* Parameters to manually update the map on a circular area */
#define RMAP_DFLT_X_CENTER	0.0
#define RMAP_DFLT_Y_CENTER	0.0
#define RMAP_DFLT_RADIUS	1.0
#define RMAP_DFLT_PROBA		0.0
typedef struct rmapCircleParams {
  double	xCenter;
  double	yCenter;
  double	radius;
  double	probaObstacle;
} rmapCircleParams;

/* Parameters to update the map on a circular area centered at the current
   robot position */
typedef struct rmapRadiusParams {
  double	radius;
  double	probaObstacle;
} rmapRadiusParams;


/* File input/output parameters */
#define RMAP_DFLT_LOADFILE		"/tmp/rmap"

typedef struct rmapLoadParams {
  char		fileName[RMAP_MAX_STRLEN];
} rmapLoadParams;

typedef struct rmapLoadPgmParams {
  char		fileName[RMAP_MAX_STRLEN];
  double	scale;
  double	xOrigin;
  double      	yOrigin;	/* Position of the map origin in the global
				   frame */ 
  double	robotRadius;	/* Radius of the robot */
} rmapLoadPgmParams;

#define RMAP_DFLT_SAVEFILE		"/tmp/rmap"
#define RMAP_DFLT_SAVENUM		0

typedef struct rmapSaveParams {
  char		fileName[RMAP_MAX_STRLEN];
  int		number;
} rmapSaveParams;

/***********************************************************************/
/* Display params */

#define RMAP_DEFAULT_DPY_SERVER	"localhost"
#define RMAP_DEFAULT_DPY_FILE		"/tmp/tmpGdheMap"
#define RMAP_DEFAULT_DPY_NUMBER	0
#define RMAP_DEFAULT_DPY_MERGED_PROBAS	RMAP_TRUE
#define RMAP_DEFAULT_DPY_GROWED_PROBAS	RMAP_TRUE

typedef struct rmapDisplayParams {
  char		serverName[RMAP_MAX_STRLEN];
  char		fileName[RMAP_MAX_STRLEN];
  int		fileNumber;
  rmapBoolean	mergedProbas;
  rmapBoolean	growedProbas;
} rmapDisplayParams;

#endif
